==> php55-owncloud-8.2.2.tgz: share/owncloud/apps/files/l10n/nb_NO.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Lagringsplass ikke tilgjengelig",
    "Storage invalid" : "Lagringsplass ugyldig",
    "Unknown error" : "Ukjent feil",
    "Could not move %s - File with this name already exists" : "Kan ikke flytte %s - En fil med samme navn finnes allerede",
    "Could not move %s" : "Kunne ikke flytte %s",
    "Permission denied" : "Tilgang nektet",
    "The target folder has been moved or deleted." : "Målmappen er blitt flyttet eller slettet.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Navnet %s brukes allerede i mappen %s. Velg et annet navn.",
    "Error when creating the file" : "Feil ved oppretting av filen",
    "Error when creating the folder" : "Feil ved oppretting av mappen",
    "Unable to set upload directory." : "Kunne ikke sette opplastingskatalog.",
    "Invalid Token" : "Ugyldig nøkkel",
    "No file was uploaded. Unknown error" : "Ingen filer ble lastet opp. Ukjent feil.",
    "There is no error, the file uploaded with success" : "Pust ut, ingen feil. Filen ble lastet opp problemfritt",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Filstørrelsen overskrider maksgrensedirektivet upload_max_filesize i php.ini-konfigurasjonen.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Filen du prøvde å laste opp var større enn grensen satt i MAX_FILE_SIZE i HTML-skjemaet.",
    "The uploaded file was only partially uploaded" : "Filen du prøvde å laste opp ble kun delvis lastet opp",
    "No file was uploaded" : "Ingen filer ble lastet opp",
    "Missing a temporary folder" : "Mangler midlertidig mappe",
    "Failed to write to disk" : "Klarte ikke å skrive til disk",
    "Not enough storage available" : "Ikke nok lagringsplass",
    "Upload failed. Could not find uploaded file" : "Opplasting feilet. Fant ikke opplastet fil.",
    "Upload failed. Could not get file info." : "Opplasting feilet. Klarte ikke å finne informasjon om fil.",
    "Invalid directory." : "Ugyldig katalog.",
    "Files" : "Filer",
    "All files" : "Alle filer",
    "Favorites" : "Favoritter",
    "Home" : "Hjem",
    "Close" : "Lukk",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke laste opp {filename} fordi det er en mappe eller har 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "Total filstørrelse {size1} overstiger grense for opplasting {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp size1} men bare {size2} er ledig",
    "Upload cancelled." : "Opplasting avbrutt.",
    "Could not get result from server." : "Fikk ikke resultat fra serveren.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Filopplasting pågår. Forlater du siden nå avbrytes opplastingen.",
    "Actions" : "Handlinger",
    "Download" : "Last ned",
    "Rename" : "Gi nytt navn",
    "Delete" : "Slett",
    "Details" : "Detaljer",
    "Select" : "Velg",
    "Pending" : "Ventende",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Operasjonen er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
    "Error moving file." : "Feil ved flytting av fil.",
    "Error moving file" : "Feil ved flytting av fil",
    "Error" : "Feil",
    "{new_name} already exists" : "{new_name} finnes allerede",
    "Could not rename file" : "Klarte ikke å gi nytt navn til fil",
    "Could not create file" : "Klarte ikke å opprette fil",
    "Could not create folder" : "Klarte ikke å opprette mappe",
    "Error deleting file." : "Feil ved sletting av fil.",
    "No entries in this folder match '{filter}'" : "Ingen oppføringer i denne mappen stemmer med '{filter}'",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagringsplass for {owner} er full, filer kan ikke oppdateres eller synkroniseres lenger!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lagringsplass er oppbrukt, filer kan ikke lenger oppdateres eller synkroniseres!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lagringsplass er nesten brukt opp ([usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : [" stemmer med '{filter}'"," stemmer med '{filter}'"],
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Er favoritt",
    "Favorite" : "Gjør til favoritt",
    "{newname} already exists" : "{newname} finnes allerede",
    "Upload" : "Last opp",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekstfil.txt",
    "Folder" : "Mappe",
    "New folder" : "Ny mappe",
    "An error occurred while trying to update the tags" : "En feil oppstod under oppdatering av taggene",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mappe ble <strong>opprettet</strong>",
    "A file or folder has been <strong>changed</strong>" : "En fil eller mappe ble <strong>endret</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begrens varsling om oppretting og endringer til <strong>favorittfilene</strong> dine <em>(Kun strøm)</em>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe ble <strong>slettet</strong>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe ble <strong>gjenopprettet</strong>",
    "You created %1$s" : "Du opprettet %1$s",
    "%2$s created %1$s" : "%2$s opprettet %1$s",
    "%1$s was created in a public folder" : "%1$s ble opprettet i en offentlig mappe",
    "You changed %1$s" : "Du endret %1$s",
    "%2$s changed %1$s" : "%2$s endret %1$s",
    "You deleted %1$s" : "Du slettet %1$s",
    "%2$s deleted %1$s" : "%2$s slettet %1$s",
    "You restored %1$s" : "Du gjenopprettet %1$s",
    "%2$s restored %1$s" : "%2$s gjenopprettet %1$s",
    "%s could not be renamed as it has been deleted" : "%s kunne ikke gis nytt navn da den er blitt slettet",
    "%s could not be renamed" : "Kunne ikke gi nytt navn til %s",
    "Upload (max. %s)" : "Opplasting (maks. %s)",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Største opplastingsstørrelse",
    "max. possible: " : "max. mulige:",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "Med PHP-FPM kan det ta inntil 5 minutter fra denne verdien lagres til den trer i kraft.",
    "Save" : "Lagre",
    "Can not be edited from here due to insufficient permissions." : "Kan ikke redigeres her pga. manglende rettigheter.",
    "Settings" : "Innstillinger",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Bruk denne adressen for å <a href=\"%s\" target=\"_blank\">få tilgang til filene dine via WebDAV</a>",
    "Cancel upload" : "Avbryt opplasting",
    "No files in here" : "Ingen filer her",
    "Upload some content or sync with your devices!" : "Last opp noe innhold eller synkroniser med enhetene dine!",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Select all" : "Velg alle",
    "Upload too large" : "Filen er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne serveren.",
    "Files are being scanned, please wait." : "Skanner filer, vennligst vent.",
    "Currently scanning" : "Skanner nå",
    "No favorites" : "Ingen favoritter",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her"
},
"nplurals=2; plural=(n != 1);");

==> php55-owncloud-9.0.0.tgz: share/owncloud/apps/files/l10n/nb_NO.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Lagringsplass ikke tilgjengelig",
    "Storage invalid" : "Lagringsplass ugyldig",
    "Unknown error" : "Ukjent feil",
    "Unable to set upload directory." : "Kunne ikke sette opplastingskatalog.",
    "Invalid Token" : "Ugyldig nøkkel",
    "No file was uploaded. Unknown error" : "Ingen filer ble lastet opp. Ukjent feil.",
    "There is no error, the file uploaded with success" : "Pust ut, ingen feil. Filen ble lastet opp problemfritt",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Filstørrelsen overskrider maksgrensedirektivet upload_max_filesize i php.ini-konfigurasjonen.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Filen du prøvde å laste opp var større enn grensen satt i MAX_FILE_SIZE i HTML-skjemaet.",
    "The uploaded file was only partially uploaded" : "Filen du prøvde å laste opp ble kun delvis lastet opp",
    "No file was uploaded" : "Ingen filer ble lastet opp",
    "Missing a temporary folder" : "Mangler midlertidig mappe",
    "Failed to write to disk" : "Klarte ikke å skrive til disk",
    "Not enough storage available" : "Ikke nok lagringsplass",
    "The target folder has been moved or deleted." : "Målmappen er blitt flyttet eller slettet.",
    "Upload failed. Could not find uploaded file" : "Opplasting feilet. Fant ikke opplastet fil.",
    "Upload failed. Could not get file info." : "Opplasting feilet. Klarte ikke å finne informasjon om fil.",
    "Invalid directory." : "Ugyldig katalog.",
    "Files" : "Filer",
    "All files" : "Alle filer",
    "Favorites" : "Favoritter",
    "Home" : "Hjem",
    "Close" : "Lukk",
    "Upload cancelled." : "Opplasting avbrutt.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke laste opp {filename} fordi det er en mappe eller har 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "Total filstørrelse {size1} overstiger grense for opplasting {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp size1} men bare {size2} er ledig",
    "Error uploading file \"{fileName}\": {message}" : "Feil ved opplasting av fil \"{fileName}\": {message}",
    "Could not get result from server." : "Fikk ikke resultat fra serveren.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Filopplasting pågår. Forlater du siden nå avbrytes opplastingen.",
    "Actions" : "Handlinger",
    "Download" : "Last ned",
    "Rename" : "Gi nytt navn",
    "Delete" : "Slett",
    "Disconnect storage" : "Koble fra lagring",
    "Unshare" : "Avslutt deling",
    "Details" : "Detaljer",
    "Select" : "Velg",
    "Pending" : "Ventende",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Operasjonen er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
    "{newName} already exists" : "{newName} finnes allerede",
    "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
    "Could not rename \"{fileName}\"" : "Klarte ikke å omdøpe \"{fileName}\"",
    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
    "Could not create folder \"{dir}\"" : "Klarete ikke å opprette mappe \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Klarete ikke å opprette mappe \"{dir}\" fordi den finnes allerede",
    "Error deleting file \"{fileName}\"." : "Feil ved sletting av fil \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "Ingen oppføringer i denne mappen stemmer med '{filter}'",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagringsplass for {owner} er full, filer kan ikke oppdateres eller synkroniseres lenger!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lagringsplass er oppbrukt, filer kan ikke lenger oppdateres eller synkroniseres!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lagringsplass er nesten brukt opp ([usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : [" stemmer med '{filter}'"," stemmer med '{filter}'"],
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Er favoritt",
    "Favorite" : "Gjør til favoritt",
    "Folder" : "Mappe",
    "New folder" : "Ny mappe",
    "{newname} already exists" : "{newname} finnes allerede",
    "Upload" : "Last opp",
    "An error occurred while trying to update the tags" : "En feil oppstod under oppdatering av merkelappene",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mappe ble <strong>opprettet</strong>",
    "A file or folder has been <strong>changed</strong>" : "En fil eller mappe ble <strong>endret</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begrens varsling om oppretting og endringer til <strong>favorittfilene</strong> dine <em>(Kun strøm)</em>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe ble <strong>slettet</strong>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe ble <strong>gjenopprettet</strong>",
    "You created %1$s" : "Du opprettet %1$s",
    "%2$s created %1$s" : "%2$s opprettet %1$s",
    "%1$s was created in a public folder" : "%1$s ble opprettet i en offentlig mappe",
    "You changed %1$s" : "Du endret %1$s",
    "%2$s changed %1$s" : "%2$s endret %1$s",
    "You deleted %1$s" : "Du slettet %1$s",
    "%2$s deleted %1$s" : "%2$s slettet %1$s",
    "You restored %1$s" : "Du gjenopprettet %1$s",
    "%2$s restored %1$s" : "%2$s gjenopprettet %1$s",
    "Changed by %2$s" : "Endret av %2$s",
    "Deleted by %2$s" : "Slettet av %2$s",
    "Restored by %2$s" : "Gjenopprettet av %2$s",
    "Upload (max. %s)" : "Opplasting (maks. %s)",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Største opplastingsstørrelse",
    "max. possible: " : "max. mulige:",
    "Save" : "Lagre",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta 5 minutter før endringene trer i kraft.",
    "Missing permissions to edit from here." : "Manglende rettigheter til å redigere herfra.",
    "Settings" : "Innstillinger",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Bruk denne adressen for å <a href=\"%s\" target=\"_blank\">få tilgang til filene dine via WebDAV</a>",
    "Cancel upload" : "Avbryt opplasting",
    "No files in here" : "Ingen filer her",
    "Upload some content or sync with your devices!" : "Last opp noe innhold eller synkroniser med enhetene dine!",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Select all" : "Velg alle",
    "Upload too large" : "Filen er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne serveren.",
    "No favorites" : "Ingen favoritter",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekstfil.txt"
},
"nplurals=2; plural=(n != 1);");
